@@ -76,12 +76,10 @@ int main(int argc, char *argv[])
     // otherwise when logging out, session manager will ask the host to quit
     // (it's a "regular X app" after all) and then the browser will complain
     qunsetenv("SESSION_MANAGER");
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-#endif
     QApplication a(argc, argv);
     // otherwise will close when download job finishes
     a.setQuitOnLastWindowClosed(false);
+    a.setQuitLockEnabled(false);
     // applicationName etc will be set in Settings once the browser identifies to us
 
     qInstallMessageHandler(msgHandler);
